@@ -7,6 +7,7 @@ import tkMessageBox
 import tkSimpleDialog
 import threading
 import time
+import types
 
 ###############################################
 #	CUI mode class
@@ -188,12 +189,13 @@ class ftpcui:
 	def getdir(self,command):
 		if len(command) == 2:
 			if string.find(command[1],"/") >= 0:
-				print string.find(command[1],"/")
 				print "sorry <dir_name>/<subdir_name>.. not support"
 			else:
-				res = self.ftpclient.getRemoteDir(command[1])
-				if res <> C_OK:
-					self.printError("Connection Error:",self.ftpclient.getError_Obj())
+				res = self.ftpclient.getCurrentLocalDir()
+				if res == C_OK:
+					res = self.ftpclient.getRemoteDir(command[1],self.ftpclient.getMsg_Obj()[0])
+					if res <> C_OK:
+						self.printError("Connection Error:",self.ftpclient.getError_Obj())
 		else:
 			print "usage : getdir <dir_name>"
 	
@@ -313,7 +315,7 @@ class ftpgui(Frame):
 	#Print FTPy widget
 	def printGUI(self):
 		#Tk
-		self.master.title("FTPy-0.1.3")
+		self.master.title("FTPy-0.1.4")
 		
 		#Frame 
 		frameTop = Frame(self)
@@ -383,6 +385,7 @@ class ftpgui(Frame):
 	def makeMenuPopupLocal(self):
 		self.menuPopupLocal = Menu(font="system 10")
 		self.menuPopupLocal.add_command(label="Create directory",command=self.createLocalDirectory)
+		self.menuPopupLocal.add_command(label="Delete directory",command=self.deleteLocalDirectory)
 		self.menuPopupLocal.add_command(label="Delete File",command=self.deleteLocalFile)
 		self.menuPopupLocal.add_command(label="Rename",command=self.renameLocalFile)
 		
@@ -390,6 +393,7 @@ class ftpgui(Frame):
 	def makeMenuPopupRemote(self):
 		self.menuPopupRemote = Menu(font="system 10")
 		self.menuPopupRemote.add_command(label="Change mode",command=self.changeMode)
+		self.menuPopupRemote.add_command(label="Delete directory",command=self.deleteRemoteDirectory)
 		self.menuPopupRemote.add_command(label="Create directory",command=self.createRemoteDirectory)
 		self.menuPopupRemote.add_command(label="Delete File",command=self.deleteRemoteFile)
 		self.menuPopupRemote.add_command(label="Rename",command=self.renameRemoteFile)
@@ -429,13 +433,14 @@ class ftpgui(Frame):
 	def makeLocalListbox(self,frameLocal):
 		#Directory path
 		self.LocalPathVar = StringVar(); self.LocalPathVar.set("")
-		entryLocalPath = Entry(frameLocal,bg="#d9d9d9",width=40,font="system 10",textvariable=self.LocalPathVar,state=DISABLED)
+		entryLocalPath = Entry(frameLocal,bg="white",width=40,font="system 10",textvariable=self.LocalPathVar)
 		entryLocalPath.grid(row=0,column=0,columnspan=2,sticky=W)
 		#Directory list
 		self.listLocal = Listbox(frameLocal,selectmode=EXTENDED,width=40,height=10,bg="white",font="system 10")
 		scrvLocal = Scrollbar(frameLocal,orient=VERTICAL,command=self.listLocal.yview)
 		scrhLocal = Scrollbar(frameLocal,orient=HORIZONTAL,command=self.listLocal.xview)
 		self.listLocal.config(xscrollcommand=scrhLocal.set,yscrollcommand=scrvLocal.set)
+		entryLocalPath.bind("<Return>",self.pressReturnLocal)
 		self.listLocal.bind("<Double-Button-1>",self.doubleClickLocal)
 		self.listLocal.bind("<ButtonRelease-3>",self.button3ClickLocal)
 		self.listLocal.grid(row=1,column=0)
@@ -453,13 +458,14 @@ class ftpgui(Frame):
 	def makeRemoteListbox(self,frameRemote):
 		#Directory path
 		self.RemotePathVar = StringVar(); self.RemotePathVar.set("")
-		entryRemotePath = Entry(frameRemote,bg="#d9d9d9",width=40,font="system 10",textvariable=self.RemotePathVar,state=DISABLED)
+		entryRemotePath = Entry(frameRemote,bg="white",width=40,font="system 10",textvariable=self.RemotePathVar)
 		entryRemotePath.grid(row=0,column=0,columnspan=2,sticky=W)
 		#Directory list
 		self.listRemote = Listbox(frameRemote,selectmode=EXTENDED,width=40,height=10,bg="white",font="system 10")
 		scrvRemote = Scrollbar(frameRemote,orient=VERTICAL,command=self.listRemote.yview)
 		scrhRemote = Scrollbar(frameRemote,orient=HORIZONTAL,command=self.listRemote.xview)
 		self.listRemote.config(xscrollcommand=scrhRemote.set,yscrollcommand=scrvRemote.set)
+		entryRemotePath.bind("<Return>",self.pressReturnRemote)
 		self.listRemote.bind("<Double-Button-1>",self.doubleClickRemote)
 		self.listRemote.bind("<ButtonRelease-3>",self.button3ClickRemote)
 		self.listRemote.grid(row=1,column=0)
@@ -517,9 +523,12 @@ class ftpgui(Frame):
 	
 	#Print error massege
 	def printError(self,err_obj):
-		string_tmp = "abc"
-		if type(string_tmp) == type(err_obj):
+		if types.StringType == type(err_obj):
 			self.printMessage(C_RED,err_obj)
+		elif types.InstanceType == type(err_obj):
+			for e in err_obj.args:
+				self.printMessage(C_RED,str(e))
+			self.printMessage(C_BLACK,"\n")
 		else:
 			for e in err_obj:
 				self.printMessage(C_RED,e)
@@ -672,7 +681,7 @@ class ftpgui(Frame):
 	#-----------------------------------------#
 	#Output version infomation
 	def showVersion(self):
-		tkMessageBox.showinfo(title="Version",message="FTPy\nVersion 0.1.3\nCreater:shinkichi")
+		tkMessageBox.showinfo(title="Version",message="FTPy\nVersion 0.1.4")
 	
 	#-----------------------------------------#
 	#          Procedure -File Transfe-       #
@@ -723,7 +732,7 @@ class ftpgui(Frame):
 				filesize = long(item[10:22])
 				res = self.threading(method_name=self.ftpclient.getRemoteFile,method_args=(objname,objname),obj_size=filesize)
 			elif item[0] == "d":	#Directory
-				res = self.threading(method_name=self.ftpclient.getRemoteDir,method_args=(objname,"dummy"))
+				res = self.threading(method_name=self.ftpclient.getRemoteDir,method_args=(objname,self.LocalPathVar.get()))
 			if res == C_OK:
 				if self.RemotePathVar.get() == "/":
 					tmpPath = self.RemotePathVar.get()+objname
@@ -860,6 +869,27 @@ class ftpgui(Frame):
 			else:
 				self.printError(self.ftpclient.getError_Obj())
 				return C_NG
+	#Delete Remote directory
+	def deleteRemoteDirectory(self):
+		#Get select item
+		select_indexes = self.listRemote.curselection()
+		if len(select_indexes) == 0:
+			return C_NG
+		selectlist = list(select_indexes)
+		selectlist.reverse()
+		for index in selectlist:
+			item = self.listRemote.get(index)
+			#Check item
+			if item[0] == "d":	#Directory
+				dir_name = item[string.rfind(item," ")+1:]
+				self.printMessage(C_BLACK,"RMD "+dir_name)
+				#Delete file
+				res = self.ftpclient.removeRemote_dir(dir_name)
+				if res <> C_OK:
+					self.printError(self.ftpclient.getError_Obj())
+					return C_NG
+				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+
 				
 	#Delete remote file
 	def deleteRemoteFile(self):
@@ -874,7 +904,7 @@ class ftpgui(Frame):
 			#Check item
 			if item[0] == "-":	#File
 				filename = item[string.rfind(item," ")+1:]
-				self.printMessage(C_BLACK,"RMD "+filename)
+				self.printMessage(C_BLACK,"DELE "+filename)
 				#Delete file
 				res = self.ftpclient.removeRemoteFile(filename)
 				if res <> C_OK:
@@ -920,6 +950,27 @@ class ftpgui(Frame):
 			else:
 				self.printError(self.ftpclient.getError_Obj())
 				return C_NG
+	#Delete local directory
+	def deleteLocalDirectory(self):
+		#Get select item
+		select_indexes = self.listLocal.curselection()
+		if len(select_indexes) == 0:
+			return C_NG
+		selectlist = list(select_indexes)
+		selectlist.reverse()
+		for index in selectlist:
+			item = self.listLocal.get(index)
+			#Check item
+			if item[0] == "d":	#Dirctory
+				dirname = item[string.rfind(item," ")+1:]
+				self.printMessage(C_BLACK,"rmdir(" + dirname + ")")
+				#Delete Directory
+				res = self.ftpclient.deleteLocalDirectory(dirname)
+				if res <> C_OK:
+					self.printError(self.ftpclient.getError_Obj())
+					return C_NG
+				self.printMessage(C_BLUE,"OK")
+				self.refreshLocalList()
 				
 	#Delete file(Local)
 	def deleteLocalFile(self):
@@ -967,6 +1018,17 @@ class ftpgui(Frame):
 	#-----------------------------------------#
 	#          Procedure -Event Remote-       #
 	#-----------------------------------------#
+	#Press Return event(Remote)
+	def pressReturnRemote(self,event):
+		if self.connectFlag == C_ON:
+			self.printMessage(C_BLACK,"CWD "+self.RemotePathVar.get())
+			res = self.ftpclient.changeRemoteDir(self.RemotePathVar.get())
+			if res == C_OK:
+				self.printMessage(C_BLUE,self.ftpclient.getReturnMsg())
+				self.refreshRemoteList()
+			else:
+				self.printError(self.ftpclient.getError_Obj())
+
 	#Double click event(Remote)
 	def doubleClickRemote(self,event):
 		if self.lockFlag == C_ON:
@@ -998,6 +1060,17 @@ class ftpgui(Frame):
 	#-----------------------------------------#
 	#          Procedure -Event Local-        #
 	#-----------------------------------------#
+	#Press Return event(Local)
+	def pressReturnLocal(self,event):
+		self.printMessage(C_BLACK,"lcd(" + self.LocalPathVar.get() + ")")
+		res = self.ftpclient.changeLocalDir(self.LocalPathVar.get())
+		if res == C_OK:
+			self.printMessage(C_BLUE,"OK")
+			self.refreshLocalList()
+		else:
+			self.printError(self.ftpclient.getError_Obj())
+
+	
 	#Double click event(Local)
 	def doubleClickLocal(self,event):
 		#Get select item
